# -*- coding: utf-8 -*-
# Generated by Django 1.9.2 on 2016-02-24 23:31
from django.db import migrations, models


class Migration(migrations.Migration):
    initial = True

    dependencies = []

    operations = [
        migrations.CreateModel(
            name="DBFile",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("content", models.BinaryField()),
                ("name", models.CharField(max_length=255, unique=True)),
                ("size", models.IntegerField(default=0)),
                ("created_on", models.DateTimeField(auto_now_add=True)),
                ("updated_on", models.DateTimeField(auto_now=True)),
            ],
            options={"verbose_name": "DB file", "db_table": "db_file"},
        ),
    ]
